# Building From Source
Instructions on how to create a binary build from source are found in [INSTALL.md](INSTALL.md) in the source tarball.

# Binary Releases

Binary builds do not require python or numpy be installed to use. Everything needed to run PDB2PQR is included. Just unpack and use.

## Windows
+ Executable file is called "pdb2pqr.exe,"
+ Windows binaries are 32 bit and were built and tested on Windows 7 64-bit but should work on Windows XP, Vista, and 8 both 32 and 64-bit systems.

## OSX 
+ Executable is called "pdb2pqr" and should already have the executable flag set
+ OSX binaries require OSX 10.6 or newer. The OSX binary is 64-bit.

## Linux
+ Executable is called "pdb2pqr" and should already have the executable flag set.
+ Linux binaries require CentOS 6 or newer and have been tested on Ubuntu 12.04 LTS and Linux Mint 13. If you are running 64-bit Linux use the 64-bit libraries. In some cases the needed 32-bit system libraries will not be installed on a 64-bit system.
